@@ -8,7 +8,7 @@ use XML::LibXML;
 use XML::LibXML::XPathContext;
 use XML::RSS::LibXML::Namespaces qw(NS_RSS10);
 
-our $VERSION = '0.3100';
+our $VERSION = '0.3102';
 
 __PACKAGE__->mk_accessors($_) for qw(impl encoding strict namespaces modules output stylesheets _internal num_items);
 
@@ -41,7 +41,7 @@ sub new
 
 {
     # Proxy methods
-    foreach my $method qw(reset channel image add_item textinput skipDays skipHours) {
+    foreach my $method (qw(reset channel image add_item textinput skipDays skipHours)) {
         no strict 'refs';
         *{$method} = sub { my $self = shift; $self->impl->$method($self, @_) };
     }
@@ -89,7 +89,7 @@ sub add_module
     if ($args{prefix} eq '#default') {
         # no op
     } else {
-        $args{prefix} =~ /^[a-z_][a-zA-Z0-9.\-_]*$/
+        $args{prefix} =~ /^[a-zA-Z_][a-zA-Z0-9.\-_]*$/
             or croak "a namespace prefix should look like [a-z_][a-z0-9.\\-_]*";
     }
 
@@ -188,12 +188,10 @@ sub get_namespaces
         (($_->getLocalName() || '#default') => $_->getData)
     } $node->getNamespaces();
 
-#    while (my($p, $uri) = each %h) {
-#        my $prefix = XML::RSS::LibXML::Namespaces::lookup_prefix($uri);
-#        if ($prefix) {
-#            $h{$prefix} = $uri;
-#        }
-#    }
+    if ($h{rdf} && ! $h{'#default'}) {
+        $h{'#default'} = NS_RSS10;
+    }
+
     return wantarray ? %h : \%h;
 }
 
@@ -239,7 +237,6 @@ sub guess_version_from_dom
     # Test starting from the most likely candidate
     if (eval { $xc->findnodes('/rdf:RDF', $dom) }) {
         # 1.0 or 0.9.
-
         # Wrap up in evail, because we may not have registered rss10
         # namespace prefix
         if (eval { $xc->findnodes("/rdf:RDF/$rss10_prefix:channel", $dom) }) {
